# DMOTD

**D**ynamic **M**essage **O**f **T**he **D**ay is a simple piece of software that can be used to broadcast a MOTD to a group of computers or to join a server and listen for it.

## Installing

This current version is made up of a **Python Package**, which can be installed with

```bash
git clone https://github.com/monolix/dmotd # Clone the repository
cd dmotd # Change working directory
python setup.py install # Install the package
```

If you want to install it in a virtual environment, just run before installing

```sh
source <envdir>/bin/activate
```

## Documentation

You can find all the docs relative to this project on its [wiki](https://github.com/monolix/dmotd/wiki/Docs-homepage).

## Contributing

If you want to contribute to this open source project, you're free to pull-request us! We'll review your submission as soon as we can.
____
##### Did you arrive over here? Go somewhere else! This project is useless.
